@@ -2,21 +2,27 @@
 // SPDX-License-Identifier: Apache-2.0
 
 // ospray
-#include "../ImageOp.h"
+#include "fb/FrameOp.h"
 
 namespace ospray {
 
 struct OSPRAY_SDK_INTERFACE DebugFrameOp : public FrameOp
 {
-  std::unique_ptr<LiveImageOp> attach(FrameBufferView &fbView) override;
+  DebugFrameOp(api::Device &device);
+
+  std::unique_ptr<LiveFrameOpInterface> attach(
+      FrameBufferView &fbView) override;
 
   std::string toString() const override;
 };
 
 struct OSPRAY_SDK_INTERFACE LiveDebugFrameOp : public LiveFrameOp
 {
-  LiveDebugFrameOp(FrameBufferView &fbView);
-  void process(const Camera *) override;
+  LiveDebugFrameOp(api::ISPCDevice &device, FrameBufferView &fbView)
+      : LiveFrameOp(device, fbView)
+  {}
+
+  void process(void *waitEvent) override;
 };
 
 } // namespace ospray
