@@ -6,7 +6,6 @@
 
 #include "Texture.h"
 #include "volume/Volume.h"
-#include "volume/VolumetricModel.h"
 #include "volume/transferFunction/TransferFunction.h"
 // ispc shared
 #include "TextureVolumeShared.h"
@@ -18,7 +17,7 @@ struct OSPRAY_SDK_INTERFACE TextureVolume
     : public AddStructShared<Texture, ispc::TextureVolume>
 {
   TextureVolume(api::ISPCDevice &device)
-      : AddStructShared(device.getIspcrtDevice(), device)
+      : AddStructShared(device.getIspcrtContext(), device)
   {}
 
   virtual std::string toString() const override;
@@ -28,9 +27,6 @@ struct OSPRAY_SDK_INTERFACE TextureVolume
  private:
   Ref<Volume> volume;
   Ref<TransferFunction> transferFunction;
-
-  // Deprecated interface.
-  Ref<VolumetricModel> volumetricModel;
 };
 
 } // namespace ospray
